---
title: <span class="badge object-type-scalar"></span> MegaOhm
---
# <span class="badge object-type-scalar"></span> MegaOhm

Energy: Megaohm (MΩ)

## Definition

```python
# Energy: Megaohm (MΩ)
MegaOhm: typing.Literal["Mohm"] = "Mohm"
```
